@@ -101,32 +101,34 @@ class Network:
             self,
             url: str,
             data: dict,
-            max_retries: int = 3,
             backoff: float = 1.0) -> dict:
         """
-        Send HTTP POST request with retry mechanism.
+        Send HTTP POST request with infinite retry mechanism.
 
         Parameters:
         - url: API endpoint URL.
         - data: Data to be sent.
-        - max_retries: Maximum number of retries.
         - backoff: Base delay for retries.
 
         Returns:
         JSON-decoded response.
         """
-        for attempt in range(max_retries):
+        attempt = 0
+        while True:
             try:
-                async with self.session.post("https://messengerg2c6.iranlms.ir", json=data, proxy=self.client.proxy) as response:
+                async with self.session.post(
+                    "https://messengerg2c6.iranlms.ir",
+                    json=data,
+                    proxy=self.client.proxy
+                ) as response:
                     response.raise_for_status()
                     return await response.json()
             except Exception as e:
+                attempt += 1
                 self.logger.warning(
-                    f"Request error, attempt {attempt + 1}/{max_retries}: {e}")
-                if attempt < max_retries - 1:
-                    await asyncio.sleep(backoff * (2 ** attempt))
-        raise exceptions.NetworkError(
-            f"Request to {url} after {max_retries} failed")
+                    f"Request error, attempt {attempt}: {e}"
+                )
+                await asyncio.sleep(backoff * (2 ** (attempt - 1)))
 
     async def send(self, **kwargs) -> dict:
         """
